ShmgetFlagsParts

Struct ShmgetFlagsParts 

pub struct ShmgetFlagsParts {
    pub flags: ShmgetFlags,
    pub tlb_size_log_2: u32,
    pub perms: SFlag,
}
Represents a deconstructed shmflg, as passed to the shmget syscall.

Fields

flags: ShmgetFlags

Bit flags.

tlb_size_log_2: u32

Requested page size, log 2.

perms: SFlag

Requested permissions (as mode parameter to open)

Implementations

Source

impl ShmgetFlagsParts

pub fn from_shmflg(shmflg: c_int) -> Self

Split a shmflg value, as provided to the shmget syscall, into consituent parts.