pub struct ShmgetFlagsParts {
pub flags: ShmgetFlags,
pub tlb_size_log_2: u32,
pub perms: SFlag,
}Expand description
Represents a deconstructed shmflg, as passed to the shmget syscall.
Fields
flags: ShmgetFlagsBit flags.
tlb_size_log_2: u32Requested page size, log 2.
perms: SFlagRequested permissions (as mode parameter to open)
Implementations
Sourceimpl ShmgetFlagsParts
impl ShmgetFlagsParts
Sourcepub fn from_shmflg(shmflg: c_int) -> Self
pub fn from_shmflg(shmflg: c_int) -> Self
Split a shmflg value, as provided to the shmget syscall, into consituent parts.